# Codex Engine for PyQt

A universal translator for serial devices.

# Description

This is the reference implementation of Codex, a framework for managing serial communication with physical devices. 

# Features
- serial port detection
- automatic handshaking
- device profiles as drop-in plugins
- supports many styles of serial communication
- extensible

## Requirements
- pyserial
- PyQt5 or PySide2
